<?php

namespace Litecms\FaqsCategory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\FaqsCategory\Models\FaqsCategories;

class FaqsCategoriesPolicy
{

    /**
     * Determine if the given user can view the faqs_categories.
     *
     * @param UserPolicy $user
     * @param FaqsCategories $faqs_categories
     *
     * @return bool
     */
    public function view(UserPolicy $user, FaqsCategories $faqs_categories)
    {
        if ($user->canDo('faqs_category.faqs_categories.view') && $user->isAdmin()) {
            return true;
        }

        return $faqs_categories->user_id == user_id() && $faqs_categories->user_type == user_type();
    }

    /**
     * Determine if the given user can create a faqs_categories.
     *
     * @param UserPolicy $user
     * @param FaqsCategories $faqs_categories
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('faqs_category.faqs_categories.create');
    }

    /**
     * Determine if the given user can update the given faqs_categories.
     *
     * @param UserPolicy $user
     * @param FaqsCategories $faqs_categories
     *
     * @return bool
     */
    public function update(UserPolicy $user, FaqsCategories $faqs_categories)
    {
        if ($user->canDo('faqs_category.faqs_categories.edit') && $user->isAdmin()) {
            return true;
        }

        return $faqs_categories->user_id == user_id() && $faqs_categories->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given faqs_categories.
     *
     * @param UserPolicy $user
     * @param FaqsCategories $faqs_categories
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, FaqsCategories $faqs_categories)
    {
        return $faqs_categories->user_id == user_id() && $faqs_categories->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given faqs_categories.
     *
     * @param UserPolicy $user
     * @param FaqsCategories $faqs_categories
     *
     * @return bool
     */
    public function verify(UserPolicy $user, FaqsCategories $faqs_categories)
    {
        if ($user->canDo('faqs_category.faqs_categories.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given faqs_categories.
     *
     * @param UserPolicy $user
     * @param FaqsCategories $faqs_categories
     *
     * @return bool
     */
    public function approve(UserPolicy $user, FaqsCategories $faqs_categories)
    {
        if ($user->canDo('faqs_category.faqs_categories.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
